@@ -5,8 +5,8 @@
 import board
 from ulab import numpy as np
 from uhistogram import Histogram
-from circuitpython_uplot.uplot import Uplot
-from circuitpython_uplot.ucartesian import ucartesian
+from circuitpython_uplot.plot import Plot
+from circuitpython_uplot.cartesian import Cartesian
 
 # Setting Up the histogram
 data = [5, 4, 3, 2, 7, 5, 3, 3, 3, 3, 2, 9, 7, 6]
@@ -17,7 +17,7 @@ my_box.draw()
 display = board.DISPLAY
 
 # Adding the plot area
-plot = Uplot(0, 0, display.width, display.height)
+plot = Plot(0, 0, display.width, display.height)
 
 # Seeting some date to plot
 x = np.linspace(-4, 4, num=50)
@@ -25,7 +25,7 @@ constant = 1.0 / np.sqrt(2 * np.pi)
 y = constant * np.exp((-(x**2)) / 2.0)
 
 # Plotting and showing the plot
-ucartesian(plot, x, y)
+Cartesian(plot, x, y)
 
 # Adding a circle
 plot.draw_circle(radius=8, x=120, y=120)
