@@ -1,28 +1,27 @@
 # SPDX-FileCopyrightText: Copyright (c) 2023 Jose D. Montoya
 #
-# SPDX-License-Identifier: Unlicense
+# SPDX-License-Identifier: MIT
 
 import time
 from random import choice
 import board
 from ulab import numpy as np
-from circuitpython_uplot.uplot import Uplot
-from circuitpython_uplot.scatter import scatter
+from circuitpython_uplot.plot import Plot
+from circuitpython_uplot.scatter import Scatter
 
 
 # Setting up the display
 display = board.DISPLAY
 
-plot = Uplot(0, 0, display.width, display.height)
+# Adding the plot area
+plot = Plot(0, 0, display.width, display.height)
 
 # Setting up tick parameters
-plot.tick_params(tickheight=12, tickcolor=0xFF0008, tickgrid=True)
+plot.tick_params(tickx_height=12, ticky_height=12, tickcolor=0xFF0008, tickgrid=True)
 plot.axs_params(axstype="cartesian")
 a = np.linspace(1, 100)
 b = [choice(a) for _ in a]
-scatter(plot, a, b)
-
-# Seeting some date to plot
+Scatter(plot, a, b)
 
 # Plotting and showing the plot
 display.show(plot)
